<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Mezze
 * @since Mezze 1.0.0
 */
if ( ! function_exists( 'mezze_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Mezze 1.0.0
    */
    function mezze_add_blog_section() {
    	$options = mezze_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'mezze_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'mezze_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        mezze_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'mezze_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Mezze 1.0.0
    * @param array $input blog section details.
    */
    function mezze_get_blog_section_details( $input ) {
        $options = mezze_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        
        $content = array();
        switch ( $blog_content_type ) {

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 4,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 4,
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = mezze_trim_content( 15 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'mezze_filter_blog_section_details', 'mezze_get_blog_section_details' );


if ( ! function_exists( 'mezze_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Mezze 1.0.0
   *
   */
   function mezze_render_blog_section( $content_details = array() ) {
        $options = mezze_get_theme_options();
        $blog_content_type  = $options['blog_content_type'];
        $readmore = ! empty( $options['blog_readmore'] ) ? $options['blog_readmore'] : esc_html__( 'Read Full Article', 'mezze' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="latest-posts" class="relative page-section">
            <div class="wrapper">
                <?php if ( ! empty( $options['blog_title'] ) ) : ?>
                    <div class="section-header">
                        <?php if ( ! empty( $options['blog_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                        <?php endif; ?>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <div class="section-content blog-posts-wrapper" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": true, "draggable": true, "fade": false }'>
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="entry-container">
                                <img src="<?php echo esc_url( get_template_directory_uri() . '/assets/uploads/strawberry.jpg' ) ?>" class="top">
                                <img src="<?php echo esc_url( get_template_directory_uri() . '/assets/uploads/lemon.jpg' ) ?>" class="bottom">
                            
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ) ?>
                                    </span><!-- .cat-links -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <?php mezze_posted_on( $content['id'] ); ?>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->

                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="more-link"><?php echo esc_html($readmore) ?><span class="icon"></span>
                                </a>
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .section-content -->

                <div class="posts-slider-navigation">
                    <div class="slider-controls"></div>
                </div><!-- .posts-slider-navigation -->
            </div><!-- .wrapper -->
        </div><!-- #latest-posts -->

    <?php }
endif;